﻿#region --- License & Copyright Notice
/*
CRUD Services Library

Copyright 2012 Jeevan James

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
#endregion

using System.Collections.ObjectModel;
using System.Runtime.Serialization;

namespace CrudServices
{
    [DataContract]
    public sealed class SortCriterion
    {
        [DataMember(Name = "field")]
        private readonly string _fieldName;

        [DataMember(Name = "order")]
        private readonly SortOrder _order;

        public SortCriterion(string fieldName, SortOrder order = SortOrder.Ascending)
        {
            _fieldName = fieldName;
            _order = order;
        }

        public string FieldName
        {
            get { return _fieldName; }
        }

        public SortOrder Order
        {
            get { return _order; }
        }
    }

    public sealed class SortCriteria : KeyedCollection<string, SortCriterion>
    {
        protected override string GetKeyForItem(SortCriterion item)
        {
            return item.FieldName;
        }
    }

    public enum SortOrder
    {
        Ascending,
        Descending,
    }
}