﻿#region --- License & Copyright Notice
/*
CRUD Services Library

Copyright 2012 Jeevan James

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
#endregion

using System.Collections.ObjectModel;
using System.Runtime.Serialization;

namespace CrudServices
{
    [DataContract]
    public sealed class WhereCriterion
    {
        [DataMember(Name = "field")]
        private readonly string _fieldName;

        [DataMember(Name = "op")]
        private readonly WhereOperand _operand;

        [DataMember(Name = "value")]
        private readonly string _value;

        internal WhereCriterion(string fieldName, WhereOperand operand, string value)
        {
            _fieldName = fieldName;
            _operand = operand;
            _value = value;
        }

        public string FieldName
        {
            get { return _fieldName; }
        }

        public WhereOperand Operand
        {
            get { return _operand; }
        }

        public string Value
        {
            get { return _value; }
        }
    }

    public sealed class WhereCriteria : Collection<WhereCriterion>
    {
    }

    [DataContract]
    public enum WhereOperand
    {
        [EnumMember(Value = "e")]
        Equals,

        [EnumMember(Value = "ne")]
        DoesNotEqual,

        [EnumMember(Value = "gt")]
        GreaterThan,

        [EnumMember(Value = "gte")]
        GreaterThanOrEquals,

        [EnumMember(Value = "lt")]
        LessThan,

        [EnumMember(Value = "lte")]
        LessThanOrEquals,

        [EnumMember(Value = "null")]
        IsNull,

        [EnumMember(Value = "nnull")]
        NotNull,
    }
}